@@ -13,15 +13,15 @@ class PRIPEL():
         self = self
 
 
-    def apply(self, log_path, epsilon, N, k):
+    def apply(self, log_path, epsilon, N, k, result_log_path=""):
 
-        now = datetime.datetime.now()
-        date_time = now.strftime(" %m-%d-%y %H-%M-%S ")
-        head, tail = os.path.split(log_path)
-        log_name = tail.replace(".xes", "")
-        new_ending = "PRIPEL" + date_time + log_name + "_epsilon_" + str(epsilon) + "_k" + str(k) + "_N"+ str(N) + ".xes"
-
-        result_log_path = os.path.join(head, new_ending)
+        if result_log_path == "":
+            now = datetime.datetime.now()
+            date_time = now.strftime(" %m-%d-%y %H-%M-%S ")
+            head, tail = os.path.split(log_path)
+            log_name = tail.replace(".xes", "")
+            new_ending = "PRIPEL" + date_time + log_name + "_epsilon_" + str(epsilon) + "_k" + str(k) + "_N"+ str(N) + ".xes"
+            result_log_path = os.path.join(head, new_ending)
 
         starttime = datetime.datetime.now()
         log = xes_import_factory.apply(log_path)
